# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v1___common___policy_pb2___PolicyTopicEntry,
    PolicyViolationKey as google___ads___googleads___v1___common___policy_pb2___PolicyViolationKey,
)

from google.ads.google_ads.v1.proto.common.value_pb2 import (
    Value as google___ads___googleads___v1___common___value_pb2___Value,
)

from google.ads.google_ads.v1.proto.errors.account_budget_proposal_error_pb2 import (
    AccountBudgetProposalErrorEnum as google___ads___googleads___v1___errors___account_budget_proposal_error_pb2___AccountBudgetProposalErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_customizer_error_pb2 import (
    AdCustomizerErrorEnum as google___ads___googleads___v1___errors___ad_customizer_error_pb2___AdCustomizerErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_error_pb2 import (
    AdErrorEnum as google___ads___googleads___v1___errors___ad_error_pb2___AdErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_group_ad_error_pb2 import (
    AdGroupAdErrorEnum as google___ads___googleads___v1___errors___ad_group_ad_error_pb2___AdGroupAdErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_group_bid_modifier_error_pb2 import (
    AdGroupBidModifierErrorEnum as google___ads___googleads___v1___errors___ad_group_bid_modifier_error_pb2___AdGroupBidModifierErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_group_criterion_error_pb2 import (
    AdGroupCriterionErrorEnum as google___ads___googleads___v1___errors___ad_group_criterion_error_pb2___AdGroupCriterionErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_group_error_pb2 import (
    AdGroupErrorEnum as google___ads___googleads___v1___errors___ad_group_error_pb2___AdGroupErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_group_feed_error_pb2 import (
    AdGroupFeedErrorEnum as google___ads___googleads___v1___errors___ad_group_feed_error_pb2___AdGroupFeedErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_parameter_error_pb2 import (
    AdParameterErrorEnum as google___ads___googleads___v1___errors___ad_parameter_error_pb2___AdParameterErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.ad_sharing_error_pb2 import (
    AdSharingErrorEnum as google___ads___googleads___v1___errors___ad_sharing_error_pb2___AdSharingErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.adx_error_pb2 import (
    AdxErrorEnum as google___ads___googleads___v1___errors___adx_error_pb2___AdxErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.asset_error_pb2 import (
    AssetErrorEnum as google___ads___googleads___v1___errors___asset_error_pb2___AssetErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.authentication_error_pb2 import (
    AuthenticationErrorEnum as google___ads___googleads___v1___errors___authentication_error_pb2___AuthenticationErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.authorization_error_pb2 import (
    AuthorizationErrorEnum as google___ads___googleads___v1___errors___authorization_error_pb2___AuthorizationErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.bidding_error_pb2 import (
    BiddingErrorEnum as google___ads___googleads___v1___errors___bidding_error_pb2___BiddingErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.bidding_strategy_error_pb2 import (
    BiddingStrategyErrorEnum as google___ads___googleads___v1___errors___bidding_strategy_error_pb2___BiddingStrategyErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.billing_setup_error_pb2 import (
    BillingSetupErrorEnum as google___ads___googleads___v1___errors___billing_setup_error_pb2___BillingSetupErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.campaign_budget_error_pb2 import (
    CampaignBudgetErrorEnum as google___ads___googleads___v1___errors___campaign_budget_error_pb2___CampaignBudgetErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.campaign_criterion_error_pb2 import (
    CampaignCriterionErrorEnum as google___ads___googleads___v1___errors___campaign_criterion_error_pb2___CampaignCriterionErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.campaign_draft_error_pb2 import (
    CampaignDraftErrorEnum as google___ads___googleads___v1___errors___campaign_draft_error_pb2___CampaignDraftErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.campaign_error_pb2 import (
    CampaignErrorEnum as google___ads___googleads___v1___errors___campaign_error_pb2___CampaignErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.campaign_experiment_error_pb2 import (
    CampaignExperimentErrorEnum as google___ads___googleads___v1___errors___campaign_experiment_error_pb2___CampaignExperimentErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.campaign_feed_error_pb2 import (
    CampaignFeedErrorEnum as google___ads___googleads___v1___errors___campaign_feed_error_pb2___CampaignFeedErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.campaign_shared_set_error_pb2 import (
    CampaignSharedSetErrorEnum as google___ads___googleads___v1___errors___campaign_shared_set_error_pb2___CampaignSharedSetErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.change_status_error_pb2 import (
    ChangeStatusErrorEnum as google___ads___googleads___v1___errors___change_status_error_pb2___ChangeStatusErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.collection_size_error_pb2 import (
    CollectionSizeErrorEnum as google___ads___googleads___v1___errors___collection_size_error_pb2___CollectionSizeErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.context_error_pb2 import (
    ContextErrorEnum as google___ads___googleads___v1___errors___context_error_pb2___ContextErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.conversion_action_error_pb2 import (
    ConversionActionErrorEnum as google___ads___googleads___v1___errors___conversion_action_error_pb2___ConversionActionErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.conversion_adjustment_upload_error_pb2 import (
    ConversionAdjustmentUploadErrorEnum as google___ads___googleads___v1___errors___conversion_adjustment_upload_error_pb2___ConversionAdjustmentUploadErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.conversion_upload_error_pb2 import (
    ConversionUploadErrorEnum as google___ads___googleads___v1___errors___conversion_upload_error_pb2___ConversionUploadErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.country_code_error_pb2 import (
    CountryCodeErrorEnum as google___ads___googleads___v1___errors___country_code_error_pb2___CountryCodeErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.criterion_error_pb2 import (
    CriterionErrorEnum as google___ads___googleads___v1___errors___criterion_error_pb2___CriterionErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.custom_interest_error_pb2 import (
    CustomInterestErrorEnum as google___ads___googleads___v1___errors___custom_interest_error_pb2___CustomInterestErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.customer_client_link_error_pb2 import (
    CustomerClientLinkErrorEnum as google___ads___googleads___v1___errors___customer_client_link_error_pb2___CustomerClientLinkErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.customer_error_pb2 import (
    CustomerErrorEnum as google___ads___googleads___v1___errors___customer_error_pb2___CustomerErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.customer_feed_error_pb2 import (
    CustomerFeedErrorEnum as google___ads___googleads___v1___errors___customer_feed_error_pb2___CustomerFeedErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.customer_manager_link_error_pb2 import (
    CustomerManagerLinkErrorEnum as google___ads___googleads___v1___errors___customer_manager_link_error_pb2___CustomerManagerLinkErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.database_error_pb2 import (
    DatabaseErrorEnum as google___ads___googleads___v1___errors___database_error_pb2___DatabaseErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.date_error_pb2 import (
    DateErrorEnum as google___ads___googleads___v1___errors___date_error_pb2___DateErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.date_range_error_pb2 import (
    DateRangeErrorEnum as google___ads___googleads___v1___errors___date_range_error_pb2___DateRangeErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.distinct_error_pb2 import (
    DistinctErrorEnum as google___ads___googleads___v1___errors___distinct_error_pb2___DistinctErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.enum_error_pb2 import (
    EnumErrorEnum as google___ads___googleads___v1___errors___enum_error_pb2___EnumErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.extension_feed_item_error_pb2 import (
    ExtensionFeedItemErrorEnum as google___ads___googleads___v1___errors___extension_feed_item_error_pb2___ExtensionFeedItemErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.extension_setting_error_pb2 import (
    ExtensionSettingErrorEnum as google___ads___googleads___v1___errors___extension_setting_error_pb2___ExtensionSettingErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.feed_attribute_reference_error_pb2 import (
    FeedAttributeReferenceErrorEnum as google___ads___googleads___v1___errors___feed_attribute_reference_error_pb2___FeedAttributeReferenceErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.feed_error_pb2 import (
    FeedErrorEnum as google___ads___googleads___v1___errors___feed_error_pb2___FeedErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.feed_item_error_pb2 import (
    FeedItemErrorEnum as google___ads___googleads___v1___errors___feed_item_error_pb2___FeedItemErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.feed_item_target_error_pb2 import (
    FeedItemTargetErrorEnum as google___ads___googleads___v1___errors___feed_item_target_error_pb2___FeedItemTargetErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.feed_item_validation_error_pb2 import (
    FeedItemValidationErrorEnum as google___ads___googleads___v1___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.feed_mapping_error_pb2 import (
    FeedMappingErrorEnum as google___ads___googleads___v1___errors___feed_mapping_error_pb2___FeedMappingErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.field_error_pb2 import (
    FieldErrorEnum as google___ads___googleads___v1___errors___field_error_pb2___FieldErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.field_mask_error_pb2 import (
    FieldMaskErrorEnum as google___ads___googleads___v1___errors___field_mask_error_pb2___FieldMaskErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.function_error_pb2 import (
    FunctionErrorEnum as google___ads___googleads___v1___errors___function_error_pb2___FunctionErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.function_parsing_error_pb2 import (
    FunctionParsingErrorEnum as google___ads___googleads___v1___errors___function_parsing_error_pb2___FunctionParsingErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.geo_target_constant_suggestion_error_pb2 import (
    GeoTargetConstantSuggestionErrorEnum as google___ads___googleads___v1___errors___geo_target_constant_suggestion_error_pb2___GeoTargetConstantSuggestionErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.header_error_pb2 import (
    HeaderErrorEnum as google___ads___googleads___v1___errors___header_error_pb2___HeaderErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.id_error_pb2 import (
    IdErrorEnum as google___ads___googleads___v1___errors___id_error_pb2___IdErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.image_error_pb2 import (
    ImageErrorEnum as google___ads___googleads___v1___errors___image_error_pb2___ImageErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.internal_error_pb2 import (
    InternalErrorEnum as google___ads___googleads___v1___errors___internal_error_pb2___InternalErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.keyword_plan_ad_group_error_pb2 import (
    KeywordPlanAdGroupErrorEnum as google___ads___googleads___v1___errors___keyword_plan_ad_group_error_pb2___KeywordPlanAdGroupErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.keyword_plan_campaign_error_pb2 import (
    KeywordPlanCampaignErrorEnum as google___ads___googleads___v1___errors___keyword_plan_campaign_error_pb2___KeywordPlanCampaignErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.keyword_plan_error_pb2 import (
    KeywordPlanErrorEnum as google___ads___googleads___v1___errors___keyword_plan_error_pb2___KeywordPlanErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.keyword_plan_idea_error_pb2 import (
    KeywordPlanIdeaErrorEnum as google___ads___googleads___v1___errors___keyword_plan_idea_error_pb2___KeywordPlanIdeaErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.keyword_plan_keyword_error_pb2 import (
    KeywordPlanKeywordErrorEnum as google___ads___googleads___v1___errors___keyword_plan_keyword_error_pb2___KeywordPlanKeywordErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.keyword_plan_negative_keyword_error_pb2 import (
    KeywordPlanNegativeKeywordErrorEnum as google___ads___googleads___v1___errors___keyword_plan_negative_keyword_error_pb2___KeywordPlanNegativeKeywordErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.label_error_pb2 import (
    LabelErrorEnum as google___ads___googleads___v1___errors___label_error_pb2___LabelErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.language_code_error_pb2 import (
    LanguageCodeErrorEnum as google___ads___googleads___v1___errors___language_code_error_pb2___LanguageCodeErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.list_operation_error_pb2 import (
    ListOperationErrorEnum as google___ads___googleads___v1___errors___list_operation_error_pb2___ListOperationErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.manager_link_error_pb2 import (
    ManagerLinkErrorEnum as google___ads___googleads___v1___errors___manager_link_error_pb2___ManagerLinkErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.media_bundle_error_pb2 import (
    MediaBundleErrorEnum as google___ads___googleads___v1___errors___media_bundle_error_pb2___MediaBundleErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.media_file_error_pb2 import (
    MediaFileErrorEnum as google___ads___googleads___v1___errors___media_file_error_pb2___MediaFileErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.media_upload_error_pb2 import (
    MediaUploadErrorEnum as google___ads___googleads___v1___errors___media_upload_error_pb2___MediaUploadErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.multiplier_error_pb2 import (
    MultiplierErrorEnum as google___ads___googleads___v1___errors___multiplier_error_pb2___MultiplierErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.mutate_error_pb2 import (
    MutateErrorEnum as google___ads___googleads___v1___errors___mutate_error_pb2___MutateErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.mutate_job_error_pb2 import (
    MutateJobErrorEnum as google___ads___googleads___v1___errors___mutate_job_error_pb2___MutateJobErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.new_resource_creation_error_pb2 import (
    NewResourceCreationErrorEnum as google___ads___googleads___v1___errors___new_resource_creation_error_pb2___NewResourceCreationErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.not_empty_error_pb2 import (
    NotEmptyErrorEnum as google___ads___googleads___v1___errors___not_empty_error_pb2___NotEmptyErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.not_whitelisted_error_pb2 import (
    NotWhitelistedErrorEnum as google___ads___googleads___v1___errors___not_whitelisted_error_pb2___NotWhitelistedErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.null_error_pb2 import (
    NullErrorEnum as google___ads___googleads___v1___errors___null_error_pb2___NullErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.operation_access_denied_error_pb2 import (
    OperationAccessDeniedErrorEnum as google___ads___googleads___v1___errors___operation_access_denied_error_pb2___OperationAccessDeniedErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.operator_error_pb2 import (
    OperatorErrorEnum as google___ads___googleads___v1___errors___operator_error_pb2___OperatorErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.partial_failure_error_pb2 import (
    PartialFailureErrorEnum as google___ads___googleads___v1___errors___partial_failure_error_pb2___PartialFailureErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.policy_finding_error_pb2 import (
    PolicyFindingErrorEnum as google___ads___googleads___v1___errors___policy_finding_error_pb2___PolicyFindingErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.policy_validation_parameter_error_pb2 import (
    PolicyValidationParameterErrorEnum as google___ads___googleads___v1___errors___policy_validation_parameter_error_pb2___PolicyValidationParameterErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.policy_violation_error_pb2 import (
    PolicyViolationErrorEnum as google___ads___googleads___v1___errors___policy_violation_error_pb2___PolicyViolationErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.query_error_pb2 import (
    QueryErrorEnum as google___ads___googleads___v1___errors___query_error_pb2___QueryErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.quota_error_pb2 import (
    QuotaErrorEnum as google___ads___googleads___v1___errors___quota_error_pb2___QuotaErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.range_error_pb2 import (
    RangeErrorEnum as google___ads___googleads___v1___errors___range_error_pb2___RangeErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.recommendation_error_pb2 import (
    RecommendationErrorEnum as google___ads___googleads___v1___errors___recommendation_error_pb2___RecommendationErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.region_code_error_pb2 import (
    RegionCodeErrorEnum as google___ads___googleads___v1___errors___region_code_error_pb2___RegionCodeErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.request_error_pb2 import (
    RequestErrorEnum as google___ads___googleads___v1___errors___request_error_pb2___RequestErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.resource_access_denied_error_pb2 import (
    ResourceAccessDeniedErrorEnum as google___ads___googleads___v1___errors___resource_access_denied_error_pb2___ResourceAccessDeniedErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.resource_count_limit_exceeded_error_pb2 import (
    ResourceCountLimitExceededErrorEnum as google___ads___googleads___v1___errors___resource_count_limit_exceeded_error_pb2___ResourceCountLimitExceededErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.setting_error_pb2 import (
    SettingErrorEnum as google___ads___googleads___v1___errors___setting_error_pb2___SettingErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.shared_criterion_error_pb2 import (
    SharedCriterionErrorEnum as google___ads___googleads___v1___errors___shared_criterion_error_pb2___SharedCriterionErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.shared_set_error_pb2 import (
    SharedSetErrorEnum as google___ads___googleads___v1___errors___shared_set_error_pb2___SharedSetErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.size_limit_error_pb2 import (
    SizeLimitErrorEnum as google___ads___googleads___v1___errors___size_limit_error_pb2___SizeLimitErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.string_format_error_pb2 import (
    StringFormatErrorEnum as google___ads___googleads___v1___errors___string_format_error_pb2___StringFormatErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.string_length_error_pb2 import (
    StringLengthErrorEnum as google___ads___googleads___v1___errors___string_length_error_pb2___StringLengthErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.url_field_error_pb2 import (
    UrlFieldErrorEnum as google___ads___googleads___v1___errors___url_field_error_pb2___UrlFieldErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.user_list_error_pb2 import (
    UserListErrorEnum as google___ads___googleads___v1___errors___user_list_error_pb2___UserListErrorEnum,
)

from google.ads.google_ads.v1.proto.errors.youtube_video_registration_error_pb2 import (
    YoutubeVideoRegistrationErrorEnum as google___ads___googleads___v1___errors___youtube_video_registration_error_pb2___YoutubeVideoRegistrationErrorEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GoogleAdsFailure(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def errors(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[GoogleAdsError]: ...

    def __init__(self,
        *,
        errors : typing___Optional[typing___Iterable[GoogleAdsError]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GoogleAdsFailure: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"errors"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"errors",b"errors"]) -> None: ...

class GoogleAdsError(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    message = ... # type: typing___Text

    @property
    def error_code(self) -> ErrorCode: ...

    @property
    def trigger(self) -> google___ads___googleads___v1___common___value_pb2___Value: ...

    @property
    def location(self) -> ErrorLocation: ...

    @property
    def details(self) -> ErrorDetails: ...

    def __init__(self,
        *,
        error_code : typing___Optional[ErrorCode] = None,
        message : typing___Optional[typing___Text] = None,
        trigger : typing___Optional[google___ads___googleads___v1___common___value_pb2___Value] = None,
        location : typing___Optional[ErrorLocation] = None,
        details : typing___Optional[ErrorDetails] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GoogleAdsError: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"details",u"error_code",u"location",u"trigger"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"details",u"error_code",u"location",u"message",u"trigger"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"details",b"details",u"error_code",b"error_code",u"location",b"location",u"trigger",b"trigger"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"details",b"details",u"error_code",b"error_code",u"location",b"location",u"message",b"message",u"trigger",b"trigger"]) -> None: ...

class ErrorCode(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    request_error = ... # type: google___ads___googleads___v1___errors___request_error_pb2___RequestErrorEnum.RequestError
    bidding_strategy_error = ... # type: google___ads___googleads___v1___errors___bidding_strategy_error_pb2___BiddingStrategyErrorEnum.BiddingStrategyError
    url_field_error = ... # type: google___ads___googleads___v1___errors___url_field_error_pb2___UrlFieldErrorEnum.UrlFieldError
    list_operation_error = ... # type: google___ads___googleads___v1___errors___list_operation_error_pb2___ListOperationErrorEnum.ListOperationError
    query_error = ... # type: google___ads___googleads___v1___errors___query_error_pb2___QueryErrorEnum.QueryError
    mutate_error = ... # type: google___ads___googleads___v1___errors___mutate_error_pb2___MutateErrorEnum.MutateError
    field_mask_error = ... # type: google___ads___googleads___v1___errors___field_mask_error_pb2___FieldMaskErrorEnum.FieldMaskError
    authorization_error = ... # type: google___ads___googleads___v1___errors___authorization_error_pb2___AuthorizationErrorEnum.AuthorizationError
    internal_error = ... # type: google___ads___googleads___v1___errors___internal_error_pb2___InternalErrorEnum.InternalError
    quota_error = ... # type: google___ads___googleads___v1___errors___quota_error_pb2___QuotaErrorEnum.QuotaError
    ad_error = ... # type: google___ads___googleads___v1___errors___ad_error_pb2___AdErrorEnum.AdError
    ad_group_error = ... # type: google___ads___googleads___v1___errors___ad_group_error_pb2___AdGroupErrorEnum.AdGroupError
    campaign_budget_error = ... # type: google___ads___googleads___v1___errors___campaign_budget_error_pb2___CampaignBudgetErrorEnum.CampaignBudgetError
    campaign_error = ... # type: google___ads___googleads___v1___errors___campaign_error_pb2___CampaignErrorEnum.CampaignError
    authentication_error = ... # type: google___ads___googleads___v1___errors___authentication_error_pb2___AuthenticationErrorEnum.AuthenticationError
    ad_group_criterion_error = ... # type: google___ads___googleads___v1___errors___ad_group_criterion_error_pb2___AdGroupCriterionErrorEnum.AdGroupCriterionError
    ad_customizer_error = ... # type: google___ads___googleads___v1___errors___ad_customizer_error_pb2___AdCustomizerErrorEnum.AdCustomizerError
    ad_group_ad_error = ... # type: google___ads___googleads___v1___errors___ad_group_ad_error_pb2___AdGroupAdErrorEnum.AdGroupAdError
    ad_sharing_error = ... # type: google___ads___googleads___v1___errors___ad_sharing_error_pb2___AdSharingErrorEnum.AdSharingError
    adx_error = ... # type: google___ads___googleads___v1___errors___adx_error_pb2___AdxErrorEnum.AdxError
    asset_error = ... # type: google___ads___googleads___v1___errors___asset_error_pb2___AssetErrorEnum.AssetError
    bidding_error = ... # type: google___ads___googleads___v1___errors___bidding_error_pb2___BiddingErrorEnum.BiddingError
    campaign_criterion_error = ... # type: google___ads___googleads___v1___errors___campaign_criterion_error_pb2___CampaignCriterionErrorEnum.CampaignCriterionError
    collection_size_error = ... # type: google___ads___googleads___v1___errors___collection_size_error_pb2___CollectionSizeErrorEnum.CollectionSizeError
    country_code_error = ... # type: google___ads___googleads___v1___errors___country_code_error_pb2___CountryCodeErrorEnum.CountryCodeError
    criterion_error = ... # type: google___ads___googleads___v1___errors___criterion_error_pb2___CriterionErrorEnum.CriterionError
    customer_error = ... # type: google___ads___googleads___v1___errors___customer_error_pb2___CustomerErrorEnum.CustomerError
    date_error = ... # type: google___ads___googleads___v1___errors___date_error_pb2___DateErrorEnum.DateError
    date_range_error = ... # type: google___ads___googleads___v1___errors___date_range_error_pb2___DateRangeErrorEnum.DateRangeError
    distinct_error = ... # type: google___ads___googleads___v1___errors___distinct_error_pb2___DistinctErrorEnum.DistinctError
    feed_attribute_reference_error = ... # type: google___ads___googleads___v1___errors___feed_attribute_reference_error_pb2___FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError
    function_error = ... # type: google___ads___googleads___v1___errors___function_error_pb2___FunctionErrorEnum.FunctionError
    function_parsing_error = ... # type: google___ads___googleads___v1___errors___function_parsing_error_pb2___FunctionParsingErrorEnum.FunctionParsingError
    id_error = ... # type: google___ads___googleads___v1___errors___id_error_pb2___IdErrorEnum.IdError
    image_error = ... # type: google___ads___googleads___v1___errors___image_error_pb2___ImageErrorEnum.ImageError
    language_code_error = ... # type: google___ads___googleads___v1___errors___language_code_error_pb2___LanguageCodeErrorEnum.LanguageCodeError
    media_bundle_error = ... # type: google___ads___googleads___v1___errors___media_bundle_error_pb2___MediaBundleErrorEnum.MediaBundleError
    media_upload_error = ... # type: google___ads___googleads___v1___errors___media_upload_error_pb2___MediaUploadErrorEnum.MediaUploadError
    media_file_error = ... # type: google___ads___googleads___v1___errors___media_file_error_pb2___MediaFileErrorEnum.MediaFileError
    multiplier_error = ... # type: google___ads___googleads___v1___errors___multiplier_error_pb2___MultiplierErrorEnum.MultiplierError
    new_resource_creation_error = ... # type: google___ads___googleads___v1___errors___new_resource_creation_error_pb2___NewResourceCreationErrorEnum.NewResourceCreationError
    not_empty_error = ... # type: google___ads___googleads___v1___errors___not_empty_error_pb2___NotEmptyErrorEnum.NotEmptyError
    null_error = ... # type: google___ads___googleads___v1___errors___null_error_pb2___NullErrorEnum.NullError
    operator_error = ... # type: google___ads___googleads___v1___errors___operator_error_pb2___OperatorErrorEnum.OperatorError
    range_error = ... # type: google___ads___googleads___v1___errors___range_error_pb2___RangeErrorEnum.RangeError
    recommendation_error = ... # type: google___ads___googleads___v1___errors___recommendation_error_pb2___RecommendationErrorEnum.RecommendationError
    region_code_error = ... # type: google___ads___googleads___v1___errors___region_code_error_pb2___RegionCodeErrorEnum.RegionCodeError
    setting_error = ... # type: google___ads___googleads___v1___errors___setting_error_pb2___SettingErrorEnum.SettingError
    string_format_error = ... # type: google___ads___googleads___v1___errors___string_format_error_pb2___StringFormatErrorEnum.StringFormatError
    string_length_error = ... # type: google___ads___googleads___v1___errors___string_length_error_pb2___StringLengthErrorEnum.StringLengthError
    operation_access_denied_error = ... # type: google___ads___googleads___v1___errors___operation_access_denied_error_pb2___OperationAccessDeniedErrorEnum.OperationAccessDeniedError
    resource_access_denied_error = ... # type: google___ads___googleads___v1___errors___resource_access_denied_error_pb2___ResourceAccessDeniedErrorEnum.ResourceAccessDeniedError
    resource_count_limit_exceeded_error = ... # type: google___ads___googleads___v1___errors___resource_count_limit_exceeded_error_pb2___ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError
    youtube_video_registration_error = ... # type: google___ads___googleads___v1___errors___youtube_video_registration_error_pb2___YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError
    ad_group_bid_modifier_error = ... # type: google___ads___googleads___v1___errors___ad_group_bid_modifier_error_pb2___AdGroupBidModifierErrorEnum.AdGroupBidModifierError
    context_error = ... # type: google___ads___googleads___v1___errors___context_error_pb2___ContextErrorEnum.ContextError
    field_error = ... # type: google___ads___googleads___v1___errors___field_error_pb2___FieldErrorEnum.FieldError
    shared_set_error = ... # type: google___ads___googleads___v1___errors___shared_set_error_pb2___SharedSetErrorEnum.SharedSetError
    shared_criterion_error = ... # type: google___ads___googleads___v1___errors___shared_criterion_error_pb2___SharedCriterionErrorEnum.SharedCriterionError
    campaign_shared_set_error = ... # type: google___ads___googleads___v1___errors___campaign_shared_set_error_pb2___CampaignSharedSetErrorEnum.CampaignSharedSetError
    conversion_action_error = ... # type: google___ads___googleads___v1___errors___conversion_action_error_pb2___ConversionActionErrorEnum.ConversionActionError
    conversion_adjustment_upload_error = ... # type: google___ads___googleads___v1___errors___conversion_adjustment_upload_error_pb2___ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError
    conversion_upload_error = ... # type: google___ads___googleads___v1___errors___conversion_upload_error_pb2___ConversionUploadErrorEnum.ConversionUploadError
    header_error = ... # type: google___ads___googleads___v1___errors___header_error_pb2___HeaderErrorEnum.HeaderError
    database_error = ... # type: google___ads___googleads___v1___errors___database_error_pb2___DatabaseErrorEnum.DatabaseError
    policy_finding_error = ... # type: google___ads___googleads___v1___errors___policy_finding_error_pb2___PolicyFindingErrorEnum.PolicyFindingError
    enum_error = ... # type: google___ads___googleads___v1___errors___enum_error_pb2___EnumErrorEnum.EnumError
    keyword_plan_error = ... # type: google___ads___googleads___v1___errors___keyword_plan_error_pb2___KeywordPlanErrorEnum.KeywordPlanError
    keyword_plan_campaign_error = ... # type: google___ads___googleads___v1___errors___keyword_plan_campaign_error_pb2___KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError
    keyword_plan_negative_keyword_error = ... # type: google___ads___googleads___v1___errors___keyword_plan_negative_keyword_error_pb2___KeywordPlanNegativeKeywordErrorEnum.KeywordPlanNegativeKeywordError
    keyword_plan_ad_group_error = ... # type: google___ads___googleads___v1___errors___keyword_plan_ad_group_error_pb2___KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupError
    keyword_plan_keyword_error = ... # type: google___ads___googleads___v1___errors___keyword_plan_keyword_error_pb2___KeywordPlanKeywordErrorEnum.KeywordPlanKeywordError
    keyword_plan_idea_error = ... # type: google___ads___googleads___v1___errors___keyword_plan_idea_error_pb2___KeywordPlanIdeaErrorEnum.KeywordPlanIdeaError
    account_budget_proposal_error = ... # type: google___ads___googleads___v1___errors___account_budget_proposal_error_pb2___AccountBudgetProposalErrorEnum.AccountBudgetProposalError
    user_list_error = ... # type: google___ads___googleads___v1___errors___user_list_error_pb2___UserListErrorEnum.UserListError
    change_status_error = ... # type: google___ads___googleads___v1___errors___change_status_error_pb2___ChangeStatusErrorEnum.ChangeStatusError
    feed_error = ... # type: google___ads___googleads___v1___errors___feed_error_pb2___FeedErrorEnum.FeedError
    geo_target_constant_suggestion_error = ... # type: google___ads___googleads___v1___errors___geo_target_constant_suggestion_error_pb2___GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError
    campaign_draft_error = ... # type: google___ads___googleads___v1___errors___campaign_draft_error_pb2___CampaignDraftErrorEnum.CampaignDraftError
    feed_item_error = ... # type: google___ads___googleads___v1___errors___feed_item_error_pb2___FeedItemErrorEnum.FeedItemError
    label_error = ... # type: google___ads___googleads___v1___errors___label_error_pb2___LabelErrorEnum.LabelError
    billing_setup_error = ... # type: google___ads___googleads___v1___errors___billing_setup_error_pb2___BillingSetupErrorEnum.BillingSetupError
    customer_client_link_error = ... # type: google___ads___googleads___v1___errors___customer_client_link_error_pb2___CustomerClientLinkErrorEnum.CustomerClientLinkError
    customer_manager_link_error = ... # type: google___ads___googleads___v1___errors___customer_manager_link_error_pb2___CustomerManagerLinkErrorEnum.CustomerManagerLinkError
    feed_mapping_error = ... # type: google___ads___googleads___v1___errors___feed_mapping_error_pb2___FeedMappingErrorEnum.FeedMappingError
    customer_feed_error = ... # type: google___ads___googleads___v1___errors___customer_feed_error_pb2___CustomerFeedErrorEnum.CustomerFeedError
    ad_group_feed_error = ... # type: google___ads___googleads___v1___errors___ad_group_feed_error_pb2___AdGroupFeedErrorEnum.AdGroupFeedError
    campaign_feed_error = ... # type: google___ads___googleads___v1___errors___campaign_feed_error_pb2___CampaignFeedErrorEnum.CampaignFeedError
    custom_interest_error = ... # type: google___ads___googleads___v1___errors___custom_interest_error_pb2___CustomInterestErrorEnum.CustomInterestError
    campaign_experiment_error = ... # type: google___ads___googleads___v1___errors___campaign_experiment_error_pb2___CampaignExperimentErrorEnum.CampaignExperimentError
    extension_feed_item_error = ... # type: google___ads___googleads___v1___errors___extension_feed_item_error_pb2___ExtensionFeedItemErrorEnum.ExtensionFeedItemError
    ad_parameter_error = ... # type: google___ads___googleads___v1___errors___ad_parameter_error_pb2___AdParameterErrorEnum.AdParameterError
    feed_item_validation_error = ... # type: google___ads___googleads___v1___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationError
    extension_setting_error = ... # type: google___ads___googleads___v1___errors___extension_setting_error_pb2___ExtensionSettingErrorEnum.ExtensionSettingError
    feed_item_target_error = ... # type: google___ads___googleads___v1___errors___feed_item_target_error_pb2___FeedItemTargetErrorEnum.FeedItemTargetError
    policy_violation_error = ... # type: google___ads___googleads___v1___errors___policy_violation_error_pb2___PolicyViolationErrorEnum.PolicyViolationError
    mutate_job_error = ... # type: google___ads___googleads___v1___errors___mutate_job_error_pb2___MutateJobErrorEnum.MutateJobError
    partial_failure_error = ... # type: google___ads___googleads___v1___errors___partial_failure_error_pb2___PartialFailureErrorEnum.PartialFailureError
    policy_validation_parameter_error = ... # type: google___ads___googleads___v1___errors___policy_validation_parameter_error_pb2___PolicyValidationParameterErrorEnum.PolicyValidationParameterError
    size_limit_error = ... # type: google___ads___googleads___v1___errors___size_limit_error_pb2___SizeLimitErrorEnum.SizeLimitError
    not_whitelisted_error = ... # type: google___ads___googleads___v1___errors___not_whitelisted_error_pb2___NotWhitelistedErrorEnum.NotWhitelistedError
    manager_link_error = ... # type: google___ads___googleads___v1___errors___manager_link_error_pb2___ManagerLinkErrorEnum.ManagerLinkError

    def __init__(self,
        *,
        request_error : typing___Optional[google___ads___googleads___v1___errors___request_error_pb2___RequestErrorEnum.RequestError] = None,
        bidding_strategy_error : typing___Optional[google___ads___googleads___v1___errors___bidding_strategy_error_pb2___BiddingStrategyErrorEnum.BiddingStrategyError] = None,
        url_field_error : typing___Optional[google___ads___googleads___v1___errors___url_field_error_pb2___UrlFieldErrorEnum.UrlFieldError] = None,
        list_operation_error : typing___Optional[google___ads___googleads___v1___errors___list_operation_error_pb2___ListOperationErrorEnum.ListOperationError] = None,
        query_error : typing___Optional[google___ads___googleads___v1___errors___query_error_pb2___QueryErrorEnum.QueryError] = None,
        mutate_error : typing___Optional[google___ads___googleads___v1___errors___mutate_error_pb2___MutateErrorEnum.MutateError] = None,
        field_mask_error : typing___Optional[google___ads___googleads___v1___errors___field_mask_error_pb2___FieldMaskErrorEnum.FieldMaskError] = None,
        authorization_error : typing___Optional[google___ads___googleads___v1___errors___authorization_error_pb2___AuthorizationErrorEnum.AuthorizationError] = None,
        internal_error : typing___Optional[google___ads___googleads___v1___errors___internal_error_pb2___InternalErrorEnum.InternalError] = None,
        quota_error : typing___Optional[google___ads___googleads___v1___errors___quota_error_pb2___QuotaErrorEnum.QuotaError] = None,
        ad_error : typing___Optional[google___ads___googleads___v1___errors___ad_error_pb2___AdErrorEnum.AdError] = None,
        ad_group_error : typing___Optional[google___ads___googleads___v1___errors___ad_group_error_pb2___AdGroupErrorEnum.AdGroupError] = None,
        campaign_budget_error : typing___Optional[google___ads___googleads___v1___errors___campaign_budget_error_pb2___CampaignBudgetErrorEnum.CampaignBudgetError] = None,
        campaign_error : typing___Optional[google___ads___googleads___v1___errors___campaign_error_pb2___CampaignErrorEnum.CampaignError] = None,
        authentication_error : typing___Optional[google___ads___googleads___v1___errors___authentication_error_pb2___AuthenticationErrorEnum.AuthenticationError] = None,
        ad_group_criterion_error : typing___Optional[google___ads___googleads___v1___errors___ad_group_criterion_error_pb2___AdGroupCriterionErrorEnum.AdGroupCriterionError] = None,
        ad_customizer_error : typing___Optional[google___ads___googleads___v1___errors___ad_customizer_error_pb2___AdCustomizerErrorEnum.AdCustomizerError] = None,
        ad_group_ad_error : typing___Optional[google___ads___googleads___v1___errors___ad_group_ad_error_pb2___AdGroupAdErrorEnum.AdGroupAdError] = None,
        ad_sharing_error : typing___Optional[google___ads___googleads___v1___errors___ad_sharing_error_pb2___AdSharingErrorEnum.AdSharingError] = None,
        adx_error : typing___Optional[google___ads___googleads___v1___errors___adx_error_pb2___AdxErrorEnum.AdxError] = None,
        asset_error : typing___Optional[google___ads___googleads___v1___errors___asset_error_pb2___AssetErrorEnum.AssetError] = None,
        bidding_error : typing___Optional[google___ads___googleads___v1___errors___bidding_error_pb2___BiddingErrorEnum.BiddingError] = None,
        campaign_criterion_error : typing___Optional[google___ads___googleads___v1___errors___campaign_criterion_error_pb2___CampaignCriterionErrorEnum.CampaignCriterionError] = None,
        collection_size_error : typing___Optional[google___ads___googleads___v1___errors___collection_size_error_pb2___CollectionSizeErrorEnum.CollectionSizeError] = None,
        country_code_error : typing___Optional[google___ads___googleads___v1___errors___country_code_error_pb2___CountryCodeErrorEnum.CountryCodeError] = None,
        criterion_error : typing___Optional[google___ads___googleads___v1___errors___criterion_error_pb2___CriterionErrorEnum.CriterionError] = None,
        customer_error : typing___Optional[google___ads___googleads___v1___errors___customer_error_pb2___CustomerErrorEnum.CustomerError] = None,
        date_error : typing___Optional[google___ads___googleads___v1___errors___date_error_pb2___DateErrorEnum.DateError] = None,
        date_range_error : typing___Optional[google___ads___googleads___v1___errors___date_range_error_pb2___DateRangeErrorEnum.DateRangeError] = None,
        distinct_error : typing___Optional[google___ads___googleads___v1___errors___distinct_error_pb2___DistinctErrorEnum.DistinctError] = None,
        feed_attribute_reference_error : typing___Optional[google___ads___googleads___v1___errors___feed_attribute_reference_error_pb2___FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError] = None,
        function_error : typing___Optional[google___ads___googleads___v1___errors___function_error_pb2___FunctionErrorEnum.FunctionError] = None,
        function_parsing_error : typing___Optional[google___ads___googleads___v1___errors___function_parsing_error_pb2___FunctionParsingErrorEnum.FunctionParsingError] = None,
        id_error : typing___Optional[google___ads___googleads___v1___errors___id_error_pb2___IdErrorEnum.IdError] = None,
        image_error : typing___Optional[google___ads___googleads___v1___errors___image_error_pb2___ImageErrorEnum.ImageError] = None,
        language_code_error : typing___Optional[google___ads___googleads___v1___errors___language_code_error_pb2___LanguageCodeErrorEnum.LanguageCodeError] = None,
        media_bundle_error : typing___Optional[google___ads___googleads___v1___errors___media_bundle_error_pb2___MediaBundleErrorEnum.MediaBundleError] = None,
        media_upload_error : typing___Optional[google___ads___googleads___v1___errors___media_upload_error_pb2___MediaUploadErrorEnum.MediaUploadError] = None,
        media_file_error : typing___Optional[google___ads___googleads___v1___errors___media_file_error_pb2___MediaFileErrorEnum.MediaFileError] = None,
        multiplier_error : typing___Optional[google___ads___googleads___v1___errors___multiplier_error_pb2___MultiplierErrorEnum.MultiplierError] = None,
        new_resource_creation_error : typing___Optional[google___ads___googleads___v1___errors___new_resource_creation_error_pb2___NewResourceCreationErrorEnum.NewResourceCreationError] = None,
        not_empty_error : typing___Optional[google___ads___googleads___v1___errors___not_empty_error_pb2___NotEmptyErrorEnum.NotEmptyError] = None,
        null_error : typing___Optional[google___ads___googleads___v1___errors___null_error_pb2___NullErrorEnum.NullError] = None,
        operator_error : typing___Optional[google___ads___googleads___v1___errors___operator_error_pb2___OperatorErrorEnum.OperatorError] = None,
        range_error : typing___Optional[google___ads___googleads___v1___errors___range_error_pb2___RangeErrorEnum.RangeError] = None,
        recommendation_error : typing___Optional[google___ads___googleads___v1___errors___recommendation_error_pb2___RecommendationErrorEnum.RecommendationError] = None,
        region_code_error : typing___Optional[google___ads___googleads___v1___errors___region_code_error_pb2___RegionCodeErrorEnum.RegionCodeError] = None,
        setting_error : typing___Optional[google___ads___googleads___v1___errors___setting_error_pb2___SettingErrorEnum.SettingError] = None,
        string_format_error : typing___Optional[google___ads___googleads___v1___errors___string_format_error_pb2___StringFormatErrorEnum.StringFormatError] = None,
        string_length_error : typing___Optional[google___ads___googleads___v1___errors___string_length_error_pb2___StringLengthErrorEnum.StringLengthError] = None,
        operation_access_denied_error : typing___Optional[google___ads___googleads___v1___errors___operation_access_denied_error_pb2___OperationAccessDeniedErrorEnum.OperationAccessDeniedError] = None,
        resource_access_denied_error : typing___Optional[google___ads___googleads___v1___errors___resource_access_denied_error_pb2___ResourceAccessDeniedErrorEnum.ResourceAccessDeniedError] = None,
        resource_count_limit_exceeded_error : typing___Optional[google___ads___googleads___v1___errors___resource_count_limit_exceeded_error_pb2___ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError] = None,
        youtube_video_registration_error : typing___Optional[google___ads___googleads___v1___errors___youtube_video_registration_error_pb2___YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError] = None,
        ad_group_bid_modifier_error : typing___Optional[google___ads___googleads___v1___errors___ad_group_bid_modifier_error_pb2___AdGroupBidModifierErrorEnum.AdGroupBidModifierError] = None,
        context_error : typing___Optional[google___ads___googleads___v1___errors___context_error_pb2___ContextErrorEnum.ContextError] = None,
        field_error : typing___Optional[google___ads___googleads___v1___errors___field_error_pb2___FieldErrorEnum.FieldError] = None,
        shared_set_error : typing___Optional[google___ads___googleads___v1___errors___shared_set_error_pb2___SharedSetErrorEnum.SharedSetError] = None,
        shared_criterion_error : typing___Optional[google___ads___googleads___v1___errors___shared_criterion_error_pb2___SharedCriterionErrorEnum.SharedCriterionError] = None,
        campaign_shared_set_error : typing___Optional[google___ads___googleads___v1___errors___campaign_shared_set_error_pb2___CampaignSharedSetErrorEnum.CampaignSharedSetError] = None,
        conversion_action_error : typing___Optional[google___ads___googleads___v1___errors___conversion_action_error_pb2___ConversionActionErrorEnum.ConversionActionError] = None,
        conversion_adjustment_upload_error : typing___Optional[google___ads___googleads___v1___errors___conversion_adjustment_upload_error_pb2___ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError] = None,
        conversion_upload_error : typing___Optional[google___ads___googleads___v1___errors___conversion_upload_error_pb2___ConversionUploadErrorEnum.ConversionUploadError] = None,
        header_error : typing___Optional[google___ads___googleads___v1___errors___header_error_pb2___HeaderErrorEnum.HeaderError] = None,
        database_error : typing___Optional[google___ads___googleads___v1___errors___database_error_pb2___DatabaseErrorEnum.DatabaseError] = None,
        policy_finding_error : typing___Optional[google___ads___googleads___v1___errors___policy_finding_error_pb2___PolicyFindingErrorEnum.PolicyFindingError] = None,
        enum_error : typing___Optional[google___ads___googleads___v1___errors___enum_error_pb2___EnumErrorEnum.EnumError] = None,
        keyword_plan_error : typing___Optional[google___ads___googleads___v1___errors___keyword_plan_error_pb2___KeywordPlanErrorEnum.KeywordPlanError] = None,
        keyword_plan_campaign_error : typing___Optional[google___ads___googleads___v1___errors___keyword_plan_campaign_error_pb2___KeywordPlanCampaignErrorEnum.KeywordPlanCampaignError] = None,
        keyword_plan_negative_keyword_error : typing___Optional[google___ads___googleads___v1___errors___keyword_plan_negative_keyword_error_pb2___KeywordPlanNegativeKeywordErrorEnum.KeywordPlanNegativeKeywordError] = None,
        keyword_plan_ad_group_error : typing___Optional[google___ads___googleads___v1___errors___keyword_plan_ad_group_error_pb2___KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupError] = None,
        keyword_plan_keyword_error : typing___Optional[google___ads___googleads___v1___errors___keyword_plan_keyword_error_pb2___KeywordPlanKeywordErrorEnum.KeywordPlanKeywordError] = None,
        keyword_plan_idea_error : typing___Optional[google___ads___googleads___v1___errors___keyword_plan_idea_error_pb2___KeywordPlanIdeaErrorEnum.KeywordPlanIdeaError] = None,
        account_budget_proposal_error : typing___Optional[google___ads___googleads___v1___errors___account_budget_proposal_error_pb2___AccountBudgetProposalErrorEnum.AccountBudgetProposalError] = None,
        user_list_error : typing___Optional[google___ads___googleads___v1___errors___user_list_error_pb2___UserListErrorEnum.UserListError] = None,
        change_status_error : typing___Optional[google___ads___googleads___v1___errors___change_status_error_pb2___ChangeStatusErrorEnum.ChangeStatusError] = None,
        feed_error : typing___Optional[google___ads___googleads___v1___errors___feed_error_pb2___FeedErrorEnum.FeedError] = None,
        geo_target_constant_suggestion_error : typing___Optional[google___ads___googleads___v1___errors___geo_target_constant_suggestion_error_pb2___GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionError] = None,
        campaign_draft_error : typing___Optional[google___ads___googleads___v1___errors___campaign_draft_error_pb2___CampaignDraftErrorEnum.CampaignDraftError] = None,
        feed_item_error : typing___Optional[google___ads___googleads___v1___errors___feed_item_error_pb2___FeedItemErrorEnum.FeedItemError] = None,
        label_error : typing___Optional[google___ads___googleads___v1___errors___label_error_pb2___LabelErrorEnum.LabelError] = None,
        billing_setup_error : typing___Optional[google___ads___googleads___v1___errors___billing_setup_error_pb2___BillingSetupErrorEnum.BillingSetupError] = None,
        customer_client_link_error : typing___Optional[google___ads___googleads___v1___errors___customer_client_link_error_pb2___CustomerClientLinkErrorEnum.CustomerClientLinkError] = None,
        customer_manager_link_error : typing___Optional[google___ads___googleads___v1___errors___customer_manager_link_error_pb2___CustomerManagerLinkErrorEnum.CustomerManagerLinkError] = None,
        feed_mapping_error : typing___Optional[google___ads___googleads___v1___errors___feed_mapping_error_pb2___FeedMappingErrorEnum.FeedMappingError] = None,
        customer_feed_error : typing___Optional[google___ads___googleads___v1___errors___customer_feed_error_pb2___CustomerFeedErrorEnum.CustomerFeedError] = None,
        ad_group_feed_error : typing___Optional[google___ads___googleads___v1___errors___ad_group_feed_error_pb2___AdGroupFeedErrorEnum.AdGroupFeedError] = None,
        campaign_feed_error : typing___Optional[google___ads___googleads___v1___errors___campaign_feed_error_pb2___CampaignFeedErrorEnum.CampaignFeedError] = None,
        custom_interest_error : typing___Optional[google___ads___googleads___v1___errors___custom_interest_error_pb2___CustomInterestErrorEnum.CustomInterestError] = None,
        campaign_experiment_error : typing___Optional[google___ads___googleads___v1___errors___campaign_experiment_error_pb2___CampaignExperimentErrorEnum.CampaignExperimentError] = None,
        extension_feed_item_error : typing___Optional[google___ads___googleads___v1___errors___extension_feed_item_error_pb2___ExtensionFeedItemErrorEnum.ExtensionFeedItemError] = None,
        ad_parameter_error : typing___Optional[google___ads___googleads___v1___errors___ad_parameter_error_pb2___AdParameterErrorEnum.AdParameterError] = None,
        feed_item_validation_error : typing___Optional[google___ads___googleads___v1___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationError] = None,
        extension_setting_error : typing___Optional[google___ads___googleads___v1___errors___extension_setting_error_pb2___ExtensionSettingErrorEnum.ExtensionSettingError] = None,
        feed_item_target_error : typing___Optional[google___ads___googleads___v1___errors___feed_item_target_error_pb2___FeedItemTargetErrorEnum.FeedItemTargetError] = None,
        policy_violation_error : typing___Optional[google___ads___googleads___v1___errors___policy_violation_error_pb2___PolicyViolationErrorEnum.PolicyViolationError] = None,
        mutate_job_error : typing___Optional[google___ads___googleads___v1___errors___mutate_job_error_pb2___MutateJobErrorEnum.MutateJobError] = None,
        partial_failure_error : typing___Optional[google___ads___googleads___v1___errors___partial_failure_error_pb2___PartialFailureErrorEnum.PartialFailureError] = None,
        policy_validation_parameter_error : typing___Optional[google___ads___googleads___v1___errors___policy_validation_parameter_error_pb2___PolicyValidationParameterErrorEnum.PolicyValidationParameterError] = None,
        size_limit_error : typing___Optional[google___ads___googleads___v1___errors___size_limit_error_pb2___SizeLimitErrorEnum.SizeLimitError] = None,
        not_whitelisted_error : typing___Optional[google___ads___googleads___v1___errors___not_whitelisted_error_pb2___NotWhitelistedErrorEnum.NotWhitelistedError] = None,
        manager_link_error : typing___Optional[google___ads___googleads___v1___errors___manager_link_error_pb2___ManagerLinkErrorEnum.ManagerLinkError] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ErrorCode: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account_budget_proposal_error",u"ad_customizer_error",u"ad_error",u"ad_group_ad_error",u"ad_group_bid_modifier_error",u"ad_group_criterion_error",u"ad_group_error",u"ad_group_feed_error",u"ad_parameter_error",u"ad_sharing_error",u"adx_error",u"asset_error",u"authentication_error",u"authorization_error",u"bidding_error",u"bidding_strategy_error",u"billing_setup_error",u"campaign_budget_error",u"campaign_criterion_error",u"campaign_draft_error",u"campaign_error",u"campaign_experiment_error",u"campaign_feed_error",u"campaign_shared_set_error",u"change_status_error",u"collection_size_error",u"context_error",u"conversion_action_error",u"conversion_adjustment_upload_error",u"conversion_upload_error",u"country_code_error",u"criterion_error",u"custom_interest_error",u"customer_client_link_error",u"customer_error",u"customer_feed_error",u"customer_manager_link_error",u"database_error",u"date_error",u"date_range_error",u"distinct_error",u"enum_error",u"error_code",u"extension_feed_item_error",u"extension_setting_error",u"feed_attribute_reference_error",u"feed_error",u"feed_item_error",u"feed_item_target_error",u"feed_item_validation_error",u"feed_mapping_error",u"field_error",u"field_mask_error",u"function_error",u"function_parsing_error",u"geo_target_constant_suggestion_error",u"header_error",u"id_error",u"image_error",u"internal_error",u"keyword_plan_ad_group_error",u"keyword_plan_campaign_error",u"keyword_plan_error",u"keyword_plan_idea_error",u"keyword_plan_keyword_error",u"keyword_plan_negative_keyword_error",u"label_error",u"language_code_error",u"list_operation_error",u"manager_link_error",u"media_bundle_error",u"media_file_error",u"media_upload_error",u"multiplier_error",u"mutate_error",u"mutate_job_error",u"new_resource_creation_error",u"not_empty_error",u"not_whitelisted_error",u"null_error",u"operation_access_denied_error",u"operator_error",u"partial_failure_error",u"policy_finding_error",u"policy_validation_parameter_error",u"policy_violation_error",u"query_error",u"quota_error",u"range_error",u"recommendation_error",u"region_code_error",u"request_error",u"resource_access_denied_error",u"resource_count_limit_exceeded_error",u"setting_error",u"shared_criterion_error",u"shared_set_error",u"size_limit_error",u"string_format_error",u"string_length_error",u"url_field_error",u"user_list_error",u"youtube_video_registration_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_budget_proposal_error",u"ad_customizer_error",u"ad_error",u"ad_group_ad_error",u"ad_group_bid_modifier_error",u"ad_group_criterion_error",u"ad_group_error",u"ad_group_feed_error",u"ad_parameter_error",u"ad_sharing_error",u"adx_error",u"asset_error",u"authentication_error",u"authorization_error",u"bidding_error",u"bidding_strategy_error",u"billing_setup_error",u"campaign_budget_error",u"campaign_criterion_error",u"campaign_draft_error",u"campaign_error",u"campaign_experiment_error",u"campaign_feed_error",u"campaign_shared_set_error",u"change_status_error",u"collection_size_error",u"context_error",u"conversion_action_error",u"conversion_adjustment_upload_error",u"conversion_upload_error",u"country_code_error",u"criterion_error",u"custom_interest_error",u"customer_client_link_error",u"customer_error",u"customer_feed_error",u"customer_manager_link_error",u"database_error",u"date_error",u"date_range_error",u"distinct_error",u"enum_error",u"error_code",u"extension_feed_item_error",u"extension_setting_error",u"feed_attribute_reference_error",u"feed_error",u"feed_item_error",u"feed_item_target_error",u"feed_item_validation_error",u"feed_mapping_error",u"field_error",u"field_mask_error",u"function_error",u"function_parsing_error",u"geo_target_constant_suggestion_error",u"header_error",u"id_error",u"image_error",u"internal_error",u"keyword_plan_ad_group_error",u"keyword_plan_campaign_error",u"keyword_plan_error",u"keyword_plan_idea_error",u"keyword_plan_keyword_error",u"keyword_plan_negative_keyword_error",u"label_error",u"language_code_error",u"list_operation_error",u"manager_link_error",u"media_bundle_error",u"media_file_error",u"media_upload_error",u"multiplier_error",u"mutate_error",u"mutate_job_error",u"new_resource_creation_error",u"not_empty_error",u"not_whitelisted_error",u"null_error",u"operation_access_denied_error",u"operator_error",u"partial_failure_error",u"policy_finding_error",u"policy_validation_parameter_error",u"policy_violation_error",u"query_error",u"quota_error",u"range_error",u"recommendation_error",u"region_code_error",u"request_error",u"resource_access_denied_error",u"resource_count_limit_exceeded_error",u"setting_error",u"shared_criterion_error",u"shared_set_error",u"size_limit_error",u"string_format_error",u"string_length_error",u"url_field_error",u"user_list_error",u"youtube_video_registration_error"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account_budget_proposal_error",b"account_budget_proposal_error",u"ad_customizer_error",b"ad_customizer_error",u"ad_error",b"ad_error",u"ad_group_ad_error",b"ad_group_ad_error",u"ad_group_bid_modifier_error",b"ad_group_bid_modifier_error",u"ad_group_criterion_error",b"ad_group_criterion_error",u"ad_group_error",b"ad_group_error",u"ad_group_feed_error",b"ad_group_feed_error",u"ad_parameter_error",b"ad_parameter_error",u"ad_sharing_error",b"ad_sharing_error",u"adx_error",b"adx_error",u"asset_error",b"asset_error",u"authentication_error",b"authentication_error",u"authorization_error",b"authorization_error",u"bidding_error",b"bidding_error",u"bidding_strategy_error",b"bidding_strategy_error",u"billing_setup_error",b"billing_setup_error",u"campaign_budget_error",b"campaign_budget_error",u"campaign_criterion_error",b"campaign_criterion_error",u"campaign_draft_error",b"campaign_draft_error",u"campaign_error",b"campaign_error",u"campaign_experiment_error",b"campaign_experiment_error",u"campaign_feed_error",b"campaign_feed_error",u"campaign_shared_set_error",b"campaign_shared_set_error",u"change_status_error",b"change_status_error",u"collection_size_error",b"collection_size_error",u"context_error",b"context_error",u"conversion_action_error",b"conversion_action_error",u"conversion_adjustment_upload_error",b"conversion_adjustment_upload_error",u"conversion_upload_error",b"conversion_upload_error",u"country_code_error",b"country_code_error",u"criterion_error",b"criterion_error",u"custom_interest_error",b"custom_interest_error",u"customer_client_link_error",b"customer_client_link_error",u"customer_error",b"customer_error",u"customer_feed_error",b"customer_feed_error",u"customer_manager_link_error",b"customer_manager_link_error",u"database_error",b"database_error",u"date_error",b"date_error",u"date_range_error",b"date_range_error",u"distinct_error",b"distinct_error",u"enum_error",b"enum_error",u"error_code",b"error_code",u"extension_feed_item_error",b"extension_feed_item_error",u"extension_setting_error",b"extension_setting_error",u"feed_attribute_reference_error",b"feed_attribute_reference_error",u"feed_error",b"feed_error",u"feed_item_error",b"feed_item_error",u"feed_item_target_error",b"feed_item_target_error",u"feed_item_validation_error",b"feed_item_validation_error",u"feed_mapping_error",b"feed_mapping_error",u"field_error",b"field_error",u"field_mask_error",b"field_mask_error",u"function_error",b"function_error",u"function_parsing_error",b"function_parsing_error",u"geo_target_constant_suggestion_error",b"geo_target_constant_suggestion_error",u"header_error",b"header_error",u"id_error",b"id_error",u"image_error",b"image_error",u"internal_error",b"internal_error",u"keyword_plan_ad_group_error",b"keyword_plan_ad_group_error",u"keyword_plan_campaign_error",b"keyword_plan_campaign_error",u"keyword_plan_error",b"keyword_plan_error",u"keyword_plan_idea_error",b"keyword_plan_idea_error",u"keyword_plan_keyword_error",b"keyword_plan_keyword_error",u"keyword_plan_negative_keyword_error",b"keyword_plan_negative_keyword_error",u"label_error",b"label_error",u"language_code_error",b"language_code_error",u"list_operation_error",b"list_operation_error",u"manager_link_error",b"manager_link_error",u"media_bundle_error",b"media_bundle_error",u"media_file_error",b"media_file_error",u"media_upload_error",b"media_upload_error",u"multiplier_error",b"multiplier_error",u"mutate_error",b"mutate_error",u"mutate_job_error",b"mutate_job_error",u"new_resource_creation_error",b"new_resource_creation_error",u"not_empty_error",b"not_empty_error",u"not_whitelisted_error",b"not_whitelisted_error",u"null_error",b"null_error",u"operation_access_denied_error",b"operation_access_denied_error",u"operator_error",b"operator_error",u"partial_failure_error",b"partial_failure_error",u"policy_finding_error",b"policy_finding_error",u"policy_validation_parameter_error",b"policy_validation_parameter_error",u"policy_violation_error",b"policy_violation_error",u"query_error",b"query_error",u"quota_error",b"quota_error",u"range_error",b"range_error",u"recommendation_error",b"recommendation_error",u"region_code_error",b"region_code_error",u"request_error",b"request_error",u"resource_access_denied_error",b"resource_access_denied_error",u"resource_count_limit_exceeded_error",b"resource_count_limit_exceeded_error",u"setting_error",b"setting_error",u"shared_criterion_error",b"shared_criterion_error",u"shared_set_error",b"shared_set_error",u"size_limit_error",b"size_limit_error",u"string_format_error",b"string_format_error",u"string_length_error",b"string_length_error",u"url_field_error",b"url_field_error",u"user_list_error",b"user_list_error",u"youtube_video_registration_error",b"youtube_video_registration_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_budget_proposal_error",b"account_budget_proposal_error",u"ad_customizer_error",b"ad_customizer_error",u"ad_error",b"ad_error",u"ad_group_ad_error",b"ad_group_ad_error",u"ad_group_bid_modifier_error",b"ad_group_bid_modifier_error",u"ad_group_criterion_error",b"ad_group_criterion_error",u"ad_group_error",b"ad_group_error",u"ad_group_feed_error",b"ad_group_feed_error",u"ad_parameter_error",b"ad_parameter_error",u"ad_sharing_error",b"ad_sharing_error",u"adx_error",b"adx_error",u"asset_error",b"asset_error",u"authentication_error",b"authentication_error",u"authorization_error",b"authorization_error",u"bidding_error",b"bidding_error",u"bidding_strategy_error",b"bidding_strategy_error",u"billing_setup_error",b"billing_setup_error",u"campaign_budget_error",b"campaign_budget_error",u"campaign_criterion_error",b"campaign_criterion_error",u"campaign_draft_error",b"campaign_draft_error",u"campaign_error",b"campaign_error",u"campaign_experiment_error",b"campaign_experiment_error",u"campaign_feed_error",b"campaign_feed_error",u"campaign_shared_set_error",b"campaign_shared_set_error",u"change_status_error",b"change_status_error",u"collection_size_error",b"collection_size_error",u"context_error",b"context_error",u"conversion_action_error",b"conversion_action_error",u"conversion_adjustment_upload_error",b"conversion_adjustment_upload_error",u"conversion_upload_error",b"conversion_upload_error",u"country_code_error",b"country_code_error",u"criterion_error",b"criterion_error",u"custom_interest_error",b"custom_interest_error",u"customer_client_link_error",b"customer_client_link_error",u"customer_error",b"customer_error",u"customer_feed_error",b"customer_feed_error",u"customer_manager_link_error",b"customer_manager_link_error",u"database_error",b"database_error",u"date_error",b"date_error",u"date_range_error",b"date_range_error",u"distinct_error",b"distinct_error",u"enum_error",b"enum_error",u"error_code",b"error_code",u"extension_feed_item_error",b"extension_feed_item_error",u"extension_setting_error",b"extension_setting_error",u"feed_attribute_reference_error",b"feed_attribute_reference_error",u"feed_error",b"feed_error",u"feed_item_error",b"feed_item_error",u"feed_item_target_error",b"feed_item_target_error",u"feed_item_validation_error",b"feed_item_validation_error",u"feed_mapping_error",b"feed_mapping_error",u"field_error",b"field_error",u"field_mask_error",b"field_mask_error",u"function_error",b"function_error",u"function_parsing_error",b"function_parsing_error",u"geo_target_constant_suggestion_error",b"geo_target_constant_suggestion_error",u"header_error",b"header_error",u"id_error",b"id_error",u"image_error",b"image_error",u"internal_error",b"internal_error",u"keyword_plan_ad_group_error",b"keyword_plan_ad_group_error",u"keyword_plan_campaign_error",b"keyword_plan_campaign_error",u"keyword_plan_error",b"keyword_plan_error",u"keyword_plan_idea_error",b"keyword_plan_idea_error",u"keyword_plan_keyword_error",b"keyword_plan_keyword_error",u"keyword_plan_negative_keyword_error",b"keyword_plan_negative_keyword_error",u"label_error",b"label_error",u"language_code_error",b"language_code_error",u"list_operation_error",b"list_operation_error",u"manager_link_error",b"manager_link_error",u"media_bundle_error",b"media_bundle_error",u"media_file_error",b"media_file_error",u"media_upload_error",b"media_upload_error",u"multiplier_error",b"multiplier_error",u"mutate_error",b"mutate_error",u"mutate_job_error",b"mutate_job_error",u"new_resource_creation_error",b"new_resource_creation_error",u"not_empty_error",b"not_empty_error",u"not_whitelisted_error",b"not_whitelisted_error",u"null_error",b"null_error",u"operation_access_denied_error",b"operation_access_denied_error",u"operator_error",b"operator_error",u"partial_failure_error",b"partial_failure_error",u"policy_finding_error",b"policy_finding_error",u"policy_validation_parameter_error",b"policy_validation_parameter_error",u"policy_violation_error",b"policy_violation_error",u"query_error",b"query_error",u"quota_error",b"quota_error",u"range_error",b"range_error",u"recommendation_error",b"recommendation_error",u"region_code_error",b"region_code_error",u"request_error",b"request_error",u"resource_access_denied_error",b"resource_access_denied_error",u"resource_count_limit_exceeded_error",b"resource_count_limit_exceeded_error",u"setting_error",b"setting_error",u"shared_criterion_error",b"shared_criterion_error",u"shared_set_error",b"shared_set_error",u"size_limit_error",b"size_limit_error",u"string_format_error",b"string_format_error",u"string_length_error",b"string_length_error",u"url_field_error",b"url_field_error",u"user_list_error",b"user_list_error",u"youtube_video_registration_error",b"youtube_video_registration_error"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"error_code",b"error_code"]) -> typing_extensions___Literal["request_error","bidding_strategy_error","url_field_error","list_operation_error","query_error","mutate_error","field_mask_error","authorization_error","internal_error","quota_error","ad_error","ad_group_error","campaign_budget_error","campaign_error","authentication_error","ad_group_criterion_error","ad_customizer_error","ad_group_ad_error","ad_sharing_error","adx_error","asset_error","bidding_error","campaign_criterion_error","collection_size_error","country_code_error","criterion_error","customer_error","date_error","date_range_error","distinct_error","feed_attribute_reference_error","function_error","function_parsing_error","id_error","image_error","language_code_error","media_bundle_error","media_upload_error","media_file_error","multiplier_error","new_resource_creation_error","not_empty_error","null_error","operator_error","range_error","recommendation_error","region_code_error","setting_error","string_format_error","string_length_error","operation_access_denied_error","resource_access_denied_error","resource_count_limit_exceeded_error","youtube_video_registration_error","ad_group_bid_modifier_error","context_error","field_error","shared_set_error","shared_criterion_error","campaign_shared_set_error","conversion_action_error","conversion_adjustment_upload_error","conversion_upload_error","header_error","database_error","policy_finding_error","enum_error","keyword_plan_error","keyword_plan_campaign_error","keyword_plan_negative_keyword_error","keyword_plan_ad_group_error","keyword_plan_keyword_error","keyword_plan_idea_error","account_budget_proposal_error","user_list_error","change_status_error","feed_error","geo_target_constant_suggestion_error","campaign_draft_error","feed_item_error","label_error","billing_setup_error","customer_client_link_error","customer_manager_link_error","feed_mapping_error","customer_feed_error","ad_group_feed_error","campaign_feed_error","custom_interest_error","campaign_experiment_error","extension_feed_item_error","ad_parameter_error","feed_item_validation_error","extension_setting_error","feed_item_target_error","policy_violation_error","mutate_job_error","partial_failure_error","policy_validation_parameter_error","size_limit_error","not_whitelisted_error","manager_link_error"]: ...

class ErrorLocation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class FieldPathElement(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        field_name = ... # type: typing___Text

        @property
        def index(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            field_name : typing___Optional[typing___Text] = None,
            index : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ErrorLocation.FieldPathElement: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"index"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"field_name",u"index"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"index",b"index"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"field_name",b"field_name",u"index",b"index"]) -> None: ...


    @property
    def field_path_elements(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ErrorLocation.FieldPathElement]: ...

    def __init__(self,
        *,
        field_path_elements : typing___Optional[typing___Iterable[ErrorLocation.FieldPathElement]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ErrorLocation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"field_path_elements"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"field_path_elements",b"field_path_elements"]) -> None: ...

class ErrorDetails(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    unpublished_error_code = ... # type: typing___Text

    @property
    def policy_violation_details(self) -> PolicyViolationDetails: ...

    @property
    def policy_finding_details(self) -> PolicyFindingDetails: ...

    def __init__(self,
        *,
        unpublished_error_code : typing___Optional[typing___Text] = None,
        policy_violation_details : typing___Optional[PolicyViolationDetails] = None,
        policy_finding_details : typing___Optional[PolicyFindingDetails] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ErrorDetails: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"policy_finding_details",u"policy_violation_details"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"policy_finding_details",u"policy_violation_details",u"unpublished_error_code"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"policy_finding_details",b"policy_finding_details",u"policy_violation_details",b"policy_violation_details"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"policy_finding_details",b"policy_finding_details",u"policy_violation_details",b"policy_violation_details",u"unpublished_error_code",b"unpublished_error_code"]) -> None: ...

class PolicyViolationDetails(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    external_policy_description = ... # type: typing___Text
    external_policy_name = ... # type: typing___Text
    is_exemptible = ... # type: bool

    @property
    def key(self) -> google___ads___googleads___v1___common___policy_pb2___PolicyViolationKey: ...

    def __init__(self,
        *,
        external_policy_description : typing___Optional[typing___Text] = None,
        key : typing___Optional[google___ads___googleads___v1___common___policy_pb2___PolicyViolationKey] = None,
        external_policy_name : typing___Optional[typing___Text] = None,
        is_exemptible : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PolicyViolationDetails: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"key"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"external_policy_description",u"external_policy_name",u"is_exemptible",u"key"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"key",b"key"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"external_policy_description",b"external_policy_description",u"external_policy_name",b"external_policy_name",u"is_exemptible",b"is_exemptible",u"key",b"key"]) -> None: ...

class PolicyFindingDetails(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def policy_topic_entries(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___policy_pb2___PolicyTopicEntry]: ...

    def __init__(self,
        *,
        policy_topic_entries : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___policy_pb2___PolicyTopicEntry]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PolicyFindingDetails: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"policy_topic_entries"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"policy_topic_entries",b"policy_topic_entries"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.resources.customer_client_link_pb2 import (
    CustomerClientLink as google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetCustomerClientLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetCustomerClientLinkRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateCustomerClientLinkRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    @property
    def operation(self) -> CustomerClientLinkOperation: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operation : typing___Optional[CustomerClientLinkOperation] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCustomerClientLinkRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operation"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"operation",b"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operation",b"operation"]) -> None: ...

class CustomerClientLinkOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...

    @property
    def create(self) -> google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink: ...

    @property
    def update(self) -> google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink: ...

    def __init__(self,
        *,
        update_mask : typing___Optional[google___protobuf___field_mask_pb2___FieldMask] = None,
        create : typing___Optional[google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink] = None,
        update : typing___Optional[google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomerClientLinkOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"update",u"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"update",u"update_mask"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"update",b"update",u"update_mask",b"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"update",b"update",u"update_mask",b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"operation",b"operation"]) -> typing_extensions___Literal["create","update"]: ...

class MutateCustomerClientLinkResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def result(self) -> MutateCustomerClientLinkResult: ...

    def __init__(self,
        *,
        result : typing___Optional[MutateCustomerClientLinkResult] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCustomerClientLinkResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"result"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"result",b"result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"result",b"result"]) -> None: ...

class MutateCustomerClientLinkResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCustomerClientLinkResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.keyword_plan_competition_level_pb2 import (
    KeywordPlanCompetitionLevelEnum as google___ads___googleads___v2___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class KeywordPlanHistoricalMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    competition = ... # type: google___ads___googleads___v2___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel

    @property
    def avg_monthly_searches(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        avg_monthly_searches : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        competition : typing___Optional[google___ads___googleads___v2___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanHistoricalMetrics: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"avg_monthly_searches"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"avg_monthly_searches",u"competition"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"avg_monthly_searches",b"avg_monthly_searches"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"avg_monthly_searches",b"avg_monthly_searches",u"competition",b"competition"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class KeywordPlanKeyword(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    match_type = ... # type: google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType

    @property
    def keyword_plan_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        keyword_plan_ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        match_type : typing___Optional[google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType] = None,
        cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanKeyword: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",u"id",u"keyword_plan_ad_group",u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",u"id",u"keyword_plan_ad_group",u"match_type",u"resource_name",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",b"cpc_bid_micros",u"id",b"id",u"keyword_plan_ad_group",b"keyword_plan_ad_group",u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",b"cpc_bid_micros",u"id",b"id",u"keyword_plan_ad_group",b"keyword_plan_ad_group",u"match_type",b"match_type",u"resource_name",b"resource_name",u"text",b"text"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ConversionActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConversionActionType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ConversionActionTypeEnum.ConversionActionType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ConversionActionTypeEnum.ConversionActionType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ConversionActionTypeEnum.ConversionActionType]]: ...
        UNSPECIFIED = typing___cast(ConversionActionTypeEnum.ConversionActionType, 0)
        UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionType, 1)
        AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionType, 2)
        CLICK_TO_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionType, 3)
        GOOGLE_PLAY_DOWNLOAD = typing___cast(ConversionActionTypeEnum.ConversionActionType, 4)
        GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(ConversionActionTypeEnum.ConversionActionType, 5)
        UPLOAD_CALLS = typing___cast(ConversionActionTypeEnum.ConversionActionType, 6)
        UPLOAD_CLICKS = typing___cast(ConversionActionTypeEnum.ConversionActionType, 7)
        WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionType, 8)
        WEBSITE_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionType, 9)
    UNSPECIFIED = typing___cast(ConversionActionTypeEnum.ConversionActionType, 0)
    UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionType, 1)
    AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionType, 2)
    CLICK_TO_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionType, 3)
    GOOGLE_PLAY_DOWNLOAD = typing___cast(ConversionActionTypeEnum.ConversionActionType, 4)
    GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(ConversionActionTypeEnum.ConversionActionType, 5)
    UPLOAD_CALLS = typing___cast(ConversionActionTypeEnum.ConversionActionType, 6)
    UPLOAD_CLICKS = typing___cast(ConversionActionTypeEnum.ConversionActionType, 7)
    WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionType, 8)
    WEBSITE_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionType, 9)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionActionTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.account_budget_proposal_type_pb2 import (
    AccountBudgetProposalTypeEnum as google___ads___googleads___v1___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.account_budget_status_pb2 import (
    AccountBudgetStatusEnum as google___ads___googleads___v1___enums___account_budget_status_pb2___AccountBudgetStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.spending_limit_type_pb2 import (
    SpendingLimitTypeEnum as google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.time_type_pb2 import (
    TimeTypeEnum as google___ads___googleads___v1___enums___time_type_pb2___TimeTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AccountBudget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PendingAccountBudgetProposal(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        proposal_type = ... # type: google___ads___googleads___v1___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalType
        end_time_type = ... # type: google___ads___googleads___v1___enums___time_type_pb2___TimeTypeEnum.TimeType
        spending_limit_type = ... # type: google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType

        @property
        def account_budget_proposal(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def purchase_order_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def notes(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def creation_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def spending_limit_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            account_budget_proposal : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            proposal_type : typing___Optional[google___ads___googleads___v1___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalType] = None,
            name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            start_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            purchase_order_number : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            notes : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            creation_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            end_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            end_time_type : typing___Optional[google___ads___googleads___v1___enums___time_type_pb2___TimeTypeEnum.TimeType] = None,
            spending_limit_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            spending_limit_type : typing___Optional[google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> AccountBudget.PendingAccountBudgetProposal: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"account_budget_proposal",u"creation_date_time",u"end_date_time",u"end_time",u"end_time_type",u"name",u"notes",u"purchase_order_number",u"spending_limit",u"spending_limit_micros",u"spending_limit_type",u"start_date_time"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"account_budget_proposal",u"creation_date_time",u"end_date_time",u"end_time",u"end_time_type",u"name",u"notes",u"proposal_type",u"purchase_order_number",u"spending_limit",u"spending_limit_micros",u"spending_limit_type",u"start_date_time"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"account_budget_proposal",b"account_budget_proposal",u"creation_date_time",b"creation_date_time",u"end_date_time",b"end_date_time",u"end_time",b"end_time",u"end_time_type",b"end_time_type",u"name",b"name",u"notes",b"notes",u"purchase_order_number",b"purchase_order_number",u"spending_limit",b"spending_limit",u"spending_limit_micros",b"spending_limit_micros",u"spending_limit_type",b"spending_limit_type",u"start_date_time",b"start_date_time"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"account_budget_proposal",b"account_budget_proposal",u"creation_date_time",b"creation_date_time",u"end_date_time",b"end_date_time",u"end_time",b"end_time",u"end_time_type",b"end_time_type",u"name",b"name",u"notes",b"notes",u"proposal_type",b"proposal_type",u"purchase_order_number",b"purchase_order_number",u"spending_limit",b"spending_limit",u"spending_limit_micros",b"spending_limit_micros",u"spending_limit_type",b"spending_limit_type",u"start_date_time",b"start_date_time"]) -> None: ...
        @typing___overload
        def WhichOneof(self, oneof_group: typing_extensions___Literal[u"end_time",b"end_time"]) -> typing_extensions___Literal["end_date_time","end_time_type"]: ...
        @typing___overload
        def WhichOneof(self, oneof_group: typing_extensions___Literal[u"spending_limit",b"spending_limit"]) -> typing_extensions___Literal["spending_limit_micros","spending_limit_type"]: ...

    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v1___enums___account_budget_status_pb2___AccountBudgetStatusEnum.AccountBudgetStatus
    proposed_end_time_type = ... # type: google___ads___googleads___v1___enums___time_type_pb2___TimeTypeEnum.TimeType
    approved_end_time_type = ... # type: google___ads___googleads___v1___enums___time_type_pb2___TimeTypeEnum.TimeType
    proposed_spending_limit_type = ... # type: google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType
    approved_spending_limit_type = ... # type: google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType
    adjusted_spending_limit_type = ... # type: google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def billing_setup(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def proposed_start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def approved_start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def total_adjustments_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def amount_served_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def purchase_order_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def notes(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def pending_proposal(self) -> AccountBudget.PendingAccountBudgetProposal: ...

    @property
    def proposed_end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def approved_end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def proposed_spending_limit_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def approved_spending_limit_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def adjusted_spending_limit_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        billing_setup : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___account_budget_status_pb2___AccountBudgetStatusEnum.AccountBudgetStatus] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        proposed_start_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        approved_start_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        total_adjustments_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        amount_served_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        purchase_order_number : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        notes : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        pending_proposal : typing___Optional[AccountBudget.PendingAccountBudgetProposal] = None,
        proposed_end_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        proposed_end_time_type : typing___Optional[google___ads___googleads___v1___enums___time_type_pb2___TimeTypeEnum.TimeType] = None,
        approved_end_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        approved_end_time_type : typing___Optional[google___ads___googleads___v1___enums___time_type_pb2___TimeTypeEnum.TimeType] = None,
        proposed_spending_limit_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        proposed_spending_limit_type : typing___Optional[google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType] = None,
        approved_spending_limit_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        approved_spending_limit_type : typing___Optional[google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType] = None,
        adjusted_spending_limit_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        adjusted_spending_limit_type : typing___Optional[google___ads___googleads___v1___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AccountBudget: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"adjusted_spending_limit",u"adjusted_spending_limit_micros",u"adjusted_spending_limit_type",u"amount_served_micros",u"approved_end_date_time",u"approved_end_time",u"approved_end_time_type",u"approved_spending_limit",u"approved_spending_limit_micros",u"approved_spending_limit_type",u"approved_start_date_time",u"billing_setup",u"id",u"name",u"notes",u"pending_proposal",u"proposed_end_date_time",u"proposed_end_time",u"proposed_end_time_type",u"proposed_spending_limit",u"proposed_spending_limit_micros",u"proposed_spending_limit_type",u"proposed_start_date_time",u"purchase_order_number",u"total_adjustments_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjusted_spending_limit",u"adjusted_spending_limit_micros",u"adjusted_spending_limit_type",u"amount_served_micros",u"approved_end_date_time",u"approved_end_time",u"approved_end_time_type",u"approved_spending_limit",u"approved_spending_limit_micros",u"approved_spending_limit_type",u"approved_start_date_time",u"billing_setup",u"id",u"name",u"notes",u"pending_proposal",u"proposed_end_date_time",u"proposed_end_time",u"proposed_end_time_type",u"proposed_spending_limit",u"proposed_spending_limit_micros",u"proposed_spending_limit_type",u"proposed_start_date_time",u"purchase_order_number",u"resource_name",u"status",u"total_adjustments_micros"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"adjusted_spending_limit",b"adjusted_spending_limit",u"adjusted_spending_limit_micros",b"adjusted_spending_limit_micros",u"adjusted_spending_limit_type",b"adjusted_spending_limit_type",u"amount_served_micros",b"amount_served_micros",u"approved_end_date_time",b"approved_end_date_time",u"approved_end_time",b"approved_end_time",u"approved_end_time_type",b"approved_end_time_type",u"approved_spending_limit",b"approved_spending_limit",u"approved_spending_limit_micros",b"approved_spending_limit_micros",u"approved_spending_limit_type",b"approved_spending_limit_type",u"approved_start_date_time",b"approved_start_date_time",u"billing_setup",b"billing_setup",u"id",b"id",u"name",b"name",u"notes",b"notes",u"pending_proposal",b"pending_proposal",u"proposed_end_date_time",b"proposed_end_date_time",u"proposed_end_time",b"proposed_end_time",u"proposed_end_time_type",b"proposed_end_time_type",u"proposed_spending_limit",b"proposed_spending_limit",u"proposed_spending_limit_micros",b"proposed_spending_limit_micros",u"proposed_spending_limit_type",b"proposed_spending_limit_type",u"proposed_start_date_time",b"proposed_start_date_time",u"purchase_order_number",b"purchase_order_number",u"total_adjustments_micros",b"total_adjustments_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjusted_spending_limit",b"adjusted_spending_limit",u"adjusted_spending_limit_micros",b"adjusted_spending_limit_micros",u"adjusted_spending_limit_type",b"adjusted_spending_limit_type",u"amount_served_micros",b"amount_served_micros",u"approved_end_date_time",b"approved_end_date_time",u"approved_end_time",b"approved_end_time",u"approved_end_time_type",b"approved_end_time_type",u"approved_spending_limit",b"approved_spending_limit",u"approved_spending_limit_micros",b"approved_spending_limit_micros",u"approved_spending_limit_type",b"approved_spending_limit_type",u"approved_start_date_time",b"approved_start_date_time",u"billing_setup",b"billing_setup",u"id",b"id",u"name",b"name",u"notes",b"notes",u"pending_proposal",b"pending_proposal",u"proposed_end_date_time",b"proposed_end_date_time",u"proposed_end_time",b"proposed_end_time",u"proposed_end_time_type",b"proposed_end_time_type",u"proposed_spending_limit",b"proposed_spending_limit",u"proposed_spending_limit_micros",b"proposed_spending_limit_micros",u"proposed_spending_limit_type",b"proposed_spending_limit_type",u"proposed_start_date_time",b"proposed_start_date_time",u"purchase_order_number",b"purchase_order_number",u"resource_name",b"resource_name",u"status",b"status",u"total_adjustments_micros",b"total_adjustments_micros"]) -> None: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"adjusted_spending_limit",b"adjusted_spending_limit"]) -> typing_extensions___Literal["adjusted_spending_limit_micros","adjusted_spending_limit_type"]: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"approved_end_time",b"approved_end_time"]) -> typing_extensions___Literal["approved_end_date_time","approved_end_time_type"]: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"approved_spending_limit",b"approved_spending_limit"]) -> typing_extensions___Literal["approved_spending_limit_micros","approved_spending_limit_type"]: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"proposed_end_time",b"proposed_end_time"]) -> typing_extensions___Literal["proposed_end_date_time","proposed_end_time_type"]: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"proposed_spending_limit",b"proposed_spending_limit"]) -> typing_extensions___Literal["proposed_spending_limit_micros","proposed_spending_limit_type"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.resources.campaign_experiment_pb2 import (
    CampaignExperiment as google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetCampaignExperimentRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetCampaignExperimentRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateCampaignExperimentsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool
    validate_only = ... # type: bool

    @property
    def operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CampaignExperimentOperation]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operations : typing___Optional[typing___Iterable[CampaignExperimentOperation]] = None,
        partial_failure : typing___Optional[bool] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCampaignExperimentsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operations",u"partial_failure",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operations",b"operations",u"partial_failure",b"partial_failure",u"validate_only",b"validate_only"]) -> None: ...

class CampaignExperimentOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove = ... # type: typing___Text

    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...

    @property
    def update(self) -> google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment: ...

    def __init__(self,
        *,
        update_mask : typing___Optional[google___protobuf___field_mask_pb2___FieldMask] = None,
        update : typing___Optional[google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment] = None,
        remove : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignExperimentOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"operation",u"remove",u"update",u"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operation",u"remove",u"update",u"update_mask"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"operation",b"operation",u"remove",b"remove",u"update",b"update",u"update_mask",b"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operation",b"operation",u"remove",b"remove",u"update",b"update",u"update_mask",b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"operation",b"operation"]) -> typing_extensions___Literal["update","remove"]: ...

class MutateCampaignExperimentsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateCampaignExperimentResult]: ...

    def __init__(self,
        *,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        results : typing___Optional[typing___Iterable[MutateCampaignExperimentResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCampaignExperimentsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...

class MutateCampaignExperimentResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCampaignExperimentResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class CreateCampaignExperimentRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    validate_only = ... # type: bool

    @property
    def campaign_experiment(self) -> google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        campaign_experiment : typing___Optional[google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateCampaignExperimentRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_experiment"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment",u"customer_id",u"validate_only"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_experiment",b"campaign_experiment"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment",b"campaign_experiment",u"customer_id",b"customer_id",u"validate_only",b"validate_only"]) -> None: ...

class CreateCampaignExperimentMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    campaign_experiment = ... # type: typing___Text

    def __init__(self,
        *,
        campaign_experiment : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateCampaignExperimentMetadata: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment",b"campaign_experiment"]) -> None: ...

class GraduateCampaignExperimentRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    campaign_experiment = ... # type: typing___Text
    campaign_budget = ... # type: typing___Text

    def __init__(self,
        *,
        campaign_experiment : typing___Optional[typing___Text] = None,
        campaign_budget : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GraduateCampaignExperimentRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_budget",u"campaign_experiment"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_budget",b"campaign_budget",u"campaign_experiment",b"campaign_experiment"]) -> None: ...

class GraduateCampaignExperimentResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    graduated_campaign = ... # type: typing___Text

    def __init__(self,
        *,
        graduated_campaign : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GraduateCampaignExperimentResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"graduated_campaign"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"graduated_campaign",b"graduated_campaign"]) -> None: ...

class PromoteCampaignExperimentRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    campaign_experiment = ... # type: typing___Text

    def __init__(self,
        *,
        campaign_experiment : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PromoteCampaignExperimentRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment",b"campaign_experiment"]) -> None: ...

class EndCampaignExperimentRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    campaign_experiment = ... # type: typing___Text

    def __init__(self,
        *,
        campaign_experiment : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> EndCampaignExperimentRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_experiment",b"campaign_experiment"]) -> None: ...

class ListCampaignExperimentAsyncErrorsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    page_token = ... # type: typing___Text
    page_size = ... # type: int

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        page_token : typing___Optional[typing___Text] = None,
        page_size : typing___Optional[int] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListCampaignExperimentAsyncErrorsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",u"page_token",u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",b"page_size",u"page_token",b"page_token",u"resource_name",b"resource_name"]) -> None: ...

class ListCampaignExperimentAsyncErrorsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token = ... # type: typing___Text

    @property
    def errors(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___rpc___status_pb2___Status]: ...

    def __init__(self,
        *,
        errors : typing___Optional[typing___Iterable[google___rpc___status_pb2___Status]] = None,
        next_page_token : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListCampaignExperimentAsyncErrorsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"errors",u"next_page_token"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"errors",b"errors",u"next_page_token",b"next_page_token"]) -> None: ...
